[Scummvm-cvs-logs] CVS: scummvm/backends/PalmOS/Src palm.cpp,1.28,1.29 palm.h,1.21,1.22

Max Horn fingolfin at users.sourceforge.net
Tue Feb 24 14:55:14 CET 2004


Update of /cvsroot/scummvm/scummvm/backends/PalmOS/Src
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv12241/backends/PalmOS/Src

Modified Files:
	palm.cpp palm.h 
Log Message:
the OSystem changes we discussed on the ML (note: renaming of the existing OSystem API is not yet finished); porters will have to fix their ports to get them to compile again

Index: palm.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/backends/PalmOS/Src/palm.cpp,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -d -r1.28 -r1.29
--- palm.cpp	5 Feb 2004 14:25:34 -0000	1.28
+++ palm.cpp	24 Feb 2004 22:39:35 -0000	1.29
@@ -230,7 +230,7 @@
 
 }
 
-void OSystem_PALMOS::init_size(uint w, uint h) {
+void OSystem_PALMOS::initSize(uint w, uint h) {
 	_screenWidth = w;
 	_screenHeight = h;
 	_offScreenPitch = gVars->screenPitch;	// direct screen / flipping use this, reset later if buffered
@@ -1593,13 +1593,12 @@
 	return errNone;
 }
 
-bool OSystem_PALMOS::set_sound_proc(SoundProc proc, void *param, SoundFormat format) {
+bool OSystem_PALMOS::setSoundCallback(SoundProc proc, void *param) {
 	Boolean success = false;
 
 	if (!_sound.active) {
 		_sound.proc = proc;
 		_sound.param = param;
-		_sound.format = format;
 		_sound.active = true;	// always true when we call this function
 		
 		// try to create sound stream
@@ -1622,7 +1621,7 @@
 	return success;
 }
 
-void OSystem_PALMOS::clear_sound_proc() {
+void OSystem_PALMOS::clearSoundCallback() {
 	if (_sound.active) {
 		if (!_sound.useHandler) {
 			SndStreamStop(_sound.sndRefNum);

Index: palm.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/backends/PalmOS/Src/palm.h,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- palm.h	5 Feb 2004 14:25:34 -0000	1.21
+++ palm.h	24 Feb 2004 22:39:35 -0000	1.22
@@ -37,7 +37,6 @@
 typedef struct {
 	OSystem::SoundProc proc;
 	void *param;
-	OSystem::SoundFormat format;
 
 	SndStreamRef sndRefNum;
 	bool active, useHandler;
@@ -51,7 +50,7 @@
 
 	// Set the size of the video bitmap.
 	// Typically, 320x200
-	void init_size(uint w, uint h);
+	void initSize(uint w, uint h);
 
 	// Draw a bitmap to screen.
 	// The screen will not be updated to reflect the new bitmap
@@ -103,14 +102,14 @@
 	 * @param param		an arbitrary parameter which is stored and passed to proc.
 	 * @param format	the sample type format.
 	 */
-	bool set_sound_proc(SoundProc proc, void *param, SoundFormat format);
+	bool setSoundCallback(SoundProc proc, void *param);
 	
 	/**
 	 * Remove any audio callback previously set via set_sound_proc, thus effectively
 	 * stopping all audio output immediately.
-	 * @see set_sound_proc
+	 * @see setSoundCallback
 	 */
-	void clear_sound_proc();
+	void clearSoundCallback();
 	//@} 
 
 	// Poll cdrom status
@@ -103,14 +102,14 @@
 	
 	/**
-	 * Remove any audio callback previously set via set_sound_proc, thus effectively
+	 * Remove any audio callback previously set via setSoundCallback, thus effectively
 	 * stopping all audio output immediately.





More information about the Scummvm-git-logs mailing list